"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setExecutionParameters = exports.SqlDatabaseExecutionParameters = void 0;
const _1 = require(".");
exports.SqlDatabaseExecutionParameters = {};
const parameters = {
    'user': { type: 'string', _default: null },
    'password': { type: 'string', _default: null },
    'jdbcUrl': { type: 'string', _default: null },
    'driverDirectory': { type: 'string', _default: './' },
    'driverClass': { type: 'string', _default: null },
    'maxConcurrentConnections': { type: 'number', _default: 1 }
};
const setExecutionParameters = (credentials, continueOnFail) => {
    exports.SqlDatabaseExecutionParameters.continueOnFail = continueOnFail;
    for (const parameter of Object.keys(parameters)) {
        const input = credentials[parameter];
        const { type, _default } = parameters[parameter];
        const { input: parameterValue, isValid: parameterIsValid } = validateOrParseInput(input, type);
        (0, _1.logger)().log('debug', `[${parameter}] Validation Results: ${parameterValue} isValid: ${parameterIsValid}`);
        if (parameterIsValid) {
            exports.SqlDatabaseExecutionParameters[parameter] = parameterValue;
        }
        else {
            (0, _1.logger)().log('error', `SqlDatabaseExecutionParameters[${parameter}]: failed input validation`);
            if (!continueOnFail) {
                throw new Error("A parameter failed validation", { cause: parameter });
            }
            exports.SqlDatabaseExecutionParameters[parameter] = _default;
        }
    }
};
exports.setExecutionParameters = setExecutionParameters;
const validateOrParseInput = (input, type) => {
    switch (type) {
        case 'string':
            return validateOrParseStringInput(input);
        case 'number':
            return validateOrParseNumberInput(input);
    }
    return { input: null, isValid: false };
};
const validateOrParseNumberInput = (input) => {
    const _input = parseInt(input);
    return { input: _input, isValid: !isNaN(_input) };
};
const validateOrParseStringInput = (input) => {
    const isStringType = typeof input === 'string' || input instanceof String;
    switch (true) {
        case isStringType:
            return { input, isValid: input.length > 0 };
        case !isStringType && typeof input.toString === 'function':
            return validateOrParseStringInput(input.toString());
    }
    return { input: '', isValid: false };
};
//# sourceMappingURL=parameters.js.map